@@ -1,4 +1,5 @@
-from compiler import Compiler
+from __future__ import absolute_import
+from .compiler import Compiler
 
 def register_filter(name=None):
     def decorator(f):
@@ -26,4 +27,4 @@ try:
         return markdown.markdown(x, output_format='html5')
 
 except ImportError:
-    pass
\ No newline at end of file
+    pass
